@@ -41,10 +41,10 @@ public:
 
     void loadConfig(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
 
-    QVariantMap setting(bool agentOwned = false) const Q_DECL_OVERRIDE;
+    QVariantMap setting() const Q_DECL_OVERRIDE;
 
 private:
-    Ui::PPPWidget * m_ui;
+    Ui::PPPWidget *m_ui;
 };
 
 #endif // PLASMA_NM_PPP_WIDGET_H
