@@ -51,7 +51,7 @@ PptpSettingWidget::PptpSettingWidget(const NetworkManager::VpnSetting::Ptr &sett
     d->setting = setting;
 
     d->ui.edt_password->setPasswordOptionsEnabled(true);
-    d->ui.edt_password->setPasswordOptionEnabled(PasswordField::NotRequired, true);
+    d->ui.edt_password->setPasswordNotRequiredEnabled(true);
 
     connect(d->ui.btnAdvanced, &QPushButton::clicked, this, &PptpSettingWidget::doAdvancedDialog);
 
@@ -66,6 +66,10 @@ PptpSettingWidget::PptpSettingWidget(const NetworkManager::VpnSetting::Ptr &sett
     connect(buttons, &QDialogButtonBox::rejected, d->advancedDlg, &QDialog::reject);
     layout->addWidget(buttons);
 
+    // Connect for setting check
+    watchChangedSetting();
+
+    // Connect for validity check
     connect(d->ui.edt_gateway, &QLineEdit::textChanged, this, &PptpSettingWidget::slotWidgetChanged);
 
     KAcceleratorManager::manage(this);
