@@ -26,8 +26,7 @@
 
 #include <KPluginFactory>
 
-K_PLUGIN_FACTORY(StrongswanUiPluginFactory, registerPlugin<StrongswanUiPlugin>();)
-K_EXPORT_PLUGIN(StrongswanUiPluginFactory("plasmanetworkmanagement_strongswanui"))
+K_PLUGIN_FACTORY_WITH_JSON(StrongswanUiPluginFactory, "plasmanetworkmanagement_strongswanui.json", registerPlugin<StrongswanUiPlugin>();)
 
 StrongswanUiPlugin::StrongswanUiPlugin(QObject * parent, const QVariantList &)
     : VpnUiPlugin(parent)
@@ -81,4 +80,6 @@ bool StrongswanUiPlugin::exportConnectionSettings(const NetworkManager::Connecti
     return false;
 }
 
+#include "strongswan.moc"
+
 // vim: sw=4 sts=4 et tw=100
